summaryrefslogtreecommitdiffstats
path: root/examples/example_dcopexport.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/example_dcopexport.py')
-rw-r--r--examples/example_dcopexport.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/examples/example_dcopexport.py b/examples/example_dcopexport.py
index 024b60f..70b4e9c 100644
--- a/examples/example_dcopexport.py
+++ b/examples/example_dcopexport.py
@@ -36,7 +36,7 @@ copyright holder.
import sys
from tdecore import KApplication, KCmdLineArgs, KAboutData
from dcopexport import DCOPExObj
-from qt import QString, QStringList
+from qt import TQString, TQStringList
"""
DCOPExObj provides all of the necessary machinery to DCOP-enable
@@ -72,13 +72,13 @@ class DeadParrotObject (DCOPExObj):
# the methods available from this app via DCOP
# addMethod (<signature>, <Python method>)
- self.addMethod ('QString getParrotType()', self.get_type)
- self.addMethod ('void setParrotType (QString)', self.set_type)
- self.addMethod ('QString squawk()', self.squawk)
- self.addMethod ('QStringList adjectives()', self.adjectives)
+ self.addMethod ('TQString getParrotType()', self.get_type)
+ self.addMethod ('void setParrotType (TQString)', self.set_type)
+ self.addMethod ('TQString squawk()', self.squawk)
+ self.addMethod ('TQStringList adjectives()', self.adjectives)
# set up object variables
- self.parrot_type = QString ("Norwegian Blue")
+ self.parrot_type = TQString ("Norwegian Blue")
def get_type (self):
return self.parrot_type
@@ -94,7 +94,7 @@ class DeadParrotObject (DCOPExObj):
"a stiff", "bereft of life", "rests in peace", "metabolic processes are now history",
"off the twig", "kicked the bucket", "shuffled off his mortal coil",
"run down his curtain", "joined the bleedin' choir invisible", "THIS IS AN EX-PARROT"]
- qadjList = QStringList ()
+ qadjList = TQStringList ()
for adj in adjList:
qadjList.append (adj)